@@ -31,6 +31,8 @@
 //#define mkdir(name, modes) mkdir(name)
 #endif //!-rzr
 
+using namespace std;
+
 
 Config * Config::p_Instance = NULL;
 
@@ -164,31 +166,39 @@ char const * const Config::getKeyCommonName(EMKey key) {
 #endif
 }
 
-void Config::saveConfig() {
 
-  string dirname = string(".emilia/"); 
-  string filename = string(PACKAGE_NAME);
-
-#if HAVE_SYS_STAT_H && HAVE_SYS_TYPES_H
-  char const * const home = getenv("HOME");
-  if (home != NULL) {
-    // TODO unsafe
-    dirname = string(home) + '/' + dirname;
-    mkdir(dirname.c_str(), S_IRUSR | S_IWUSR |S_IXUSR);
-  } else {
-#ifdef RZR_PATHRELATIVE //!rzr: check w32 config save (TODO)
-    dirname = m_sExeDir + '/' ;
-    filename = string(PACKAGE_NAME) + ".cfg";
-#else
-    cerr << "Could not find environment variable HOME." << endl;
-    cerr << "Not able to read or write config file" << endl;
-    return;
-#endif
+bool Config::create_directories(std::string const & path, mode_t mode)
+{
+  int pos = 0;
+  while (pos <= path.length()) {
+    int current = path.find("/", pos);
+    if (current <0) current = path.length();
+    if (current) {
+      string const dir = path.substr(0, current);
+      // cerr << "log: io: Creating dir : " << dir << endl;
+      struct stat sb;
+      if (0 != stat(dir.c_str(), &sb)) {
+	if (0 != mkdir(dir.c_str(), mode)) {
+	  // cerr << "error: io: " << errno << " : Can't create directory \'"  << dir << "\'" << endl;
+	  return false;
+	}
+      }
+    }
+    pos = ++current;
   }
-#endif
-
-  filename = dirname  + filename;
+  return true;
+}
 
+  
+void Config::saveConfig()
+{
+  string const dirname = string(getenv("HOME") ? : ".") + "/.config/emilia/"; 
+  string const filename = dirname + string(PACKAGE_NAME);
+  
+  if (! Config::create_directories(dirname)) {
+    cerr << "error: io: Can't create directory \'" << dirname << "\'" << endl;
+  }
+  
   ofstream file(filename.c_str());
   if (!file) {
     cerr << "Couldn't open config file: " << filename << endl;
@@ -225,7 +235,7 @@ void Config::loadConfig() {
   // loading default fixes possible problems with missing values in config file
   this->setDefault();
 
-  string dirname = string(".emilia/"); 
+  string dirname = string(".config/emilia/"); 
   string filename = string(PACKAGE_NAME);
 
 #if HAVE_SYS_STAT_H && HAVE_SYS_TYPES_H
@@ -342,11 +352,11 @@ void Config::loadArgs(int & argc, char *argv[]) {
     if (strcmp(argv[a], "-dir") == 0) {
       cout << EM_DATADIR << endl;
       exit(0);
-    } else if (strcmp(argv[a], "-fullscreen") == 0) {
+    } else if (strcmp(argv[a], "--fullscreen") == 0) {
       m_bFullScreen = true;
       EM_COUT("Using fullscreen", 1);
       REMOVEARG(a, argc, argv);
-    } else if (strcmp(argv[a], "-size") == 0) {
+    } else if (strcmp(argv[a], "--size") == 0) {
       if (argc > a+2) {
         int const w= atoi(argv[a+1]);
         int const h = atoi(argv[a+2]);
@@ -358,27 +368,27 @@ void Config::loadArgs(int & argc, char *argv[]) {
       } else {
 	REMOVEARG(a, argc, argv);
       }
-    } else if (strcmp(argv[a], "-bpp") == 0) {
+    } else if (strcmp(argv[a], "--bpp") == 0) {
       if (argc > a+1) {
 	m_iBpp = atoi(argv[a+1]);
 	REMOVEARG(a, argc, argv);
       }
       EM_COUT("Using " << m_iBpp << " bpp", 1);
       REMOVEARG(a, argc, argv);
-    } else if (strcmp(argv[a], "-nosound") == 0) {
+    } else if (strcmp(argv[a], "--nosound") == 0) {
       this->setSound(0);
       this->setMusic(0);
       EM_COUT("Disabling sound", 1);
       REMOVEARG(a, argc, argv);
-    } else if (strcmp(argv[a], "-nolights") == 0) {
+    } else if (strcmp(argv[a], "--nolights") == 0) {
       this->setLights(false);
       EM_COUT("Disabling lights", 1);
       REMOVEARG(a, argc, argv);
-    } else if (strcmp(argv[a], "-nearest") == 0) {
+    } else if (strcmp(argv[a], "--nearest") == 0) {
       this->setGLFilter(EM_NEAREST);
       EM_COUT("Using nearest for texture mapping", 1);
       REMOVEARG(a, argc, argv);
-    } else if (strcmp(argv[a], "-externgl") == 0) {
+    } else if (strcmp(argv[a], "--externgl") == 0) {
       m_bExternGL = true;
       EM_COUT("Using extern GL, disabling SDL", 1);
       REMOVEARG(a, argc, argv);
@@ -423,12 +433,12 @@ void Config::setPaths(char const * const argv0) {
   m_sDataDir = string(EM_DATADIR) + "/";
   m_sExeDir = "./";
   if ( *( m_sDataDir.c_str() ) != '/' ) {
-    const char* ptr=0;
-    char* ptrw = 0;
     //cout<<"relative to exe file"<<endl;
-    ptr = (strrchr(argv0,'/')); // unix /cygwin / check win32 
+    char const * ptr = (strrchr(argv0,'/')); // unix /cygwin / check win32 
 #ifdef WIN32
-    ptrw = (strrchr(argv0,'\\')); 
+    char const * const ptrw = 0;    ptrw = (strrchr(argv0,'\\')); 
+#else 
+    char const * const ptrw = 0;
 #endif //TODO: MacOS file sep ':'   
     if ( ptrw > ptr ) ptr = ptrw;
     //    assert( (*ptr != 0) );
