@@ -10,34 +10,26 @@
 #ifndef OPENGLVISITOR_H
 #define OPENGLVISITOR_H
 
-#include "Visitor.h"
+#include "RenderVisitor.h"
 
 #define EM_GL_GCOL_TEX        0 
 #define EM_GL_GCOL_TEX_TRANS  2
 #define EM_GL_CLEAN           4
 
-class Group;
-class Shape3D;
 
-/** @author Henrik Enqvist */
-
-class OpenGLVisitor : public Visitor  {
- protected:
+class OpenGLVisitor
+  : public RenderVisitor
+{
+public:
+  static OpenGLVisitor* getInstance();
+public:
+  virtual void visit(Group* g);
+  virtual void empty();
+protected:
   OpenGLVisitor();
- public:
-  ~OpenGLVisitor();
-  static OpenGLVisitor * getInstance();
-  void visit(Group* g);
-  void empty();
-  int getMode() { return m_iMode; };
-  void setMode(int m) { m_iMode = m; };
-  static int getPolys() { return m_iPoly; };
- private:
-  int m_iMode;
-  bool m_bOffset;
-  void visit(Shape3D* s, Group* g);
-  static OpenGLVisitor * p_OpenGLVisitor;
-  static int m_iPoly;
+  virtual ~OpenGLVisitor();
+protected:
+  static OpenGLVisitor* p_OpenGLVisitor;
 };
 
 #endif // OPENGLVISITOR_H
