@@ -13,14 +13,11 @@
 #include "Private.h"
 #include "TextureUtil.h"
 #include "Config.h"
+
+#include <cassert>
 #include <iostream>
 
 #if EM_USE_SDL
-#include <SDL_opengl.h> //should fix GL portability ; instead of <OpenGL/gl.h>
-// TODO remove glu
-#if EM_DEBUG
-#include <GL/glu.h>
-#endif
 #include <SDL.h>
 #include <SDL_image.h>
 
@@ -147,20 +144,27 @@ void TextureUtil::initGrx() {
     if (njoystick != 0) {
       cerr << "The names of the joysticks are:" << endl;
       for(int a=0; a<njoystick; a++ ) {
-        cerr << "  " << SDL_JoystickName(a) << endl;
+        cerr << "  " << SDL_JoystickNameForIndex(a) << endl;
       }
-      cerr << "Using " << SDL_JoystickName(0) << endl << endl;
+      cerr << "Using " << SDL_JoystickNameForIndex(0)
+           << "( type: 0x" << hex << SDL_JoystickGetDeviceType(0) <<")"
+           << endl;
       SDL_JoystickOpen(0);
       SDL_JoystickEventState(SDL_ENABLE);
     }
   }
-
   // See if we should detect the display depth
-  if ( SDL_GetVideoInfo()->vfmt->BitsPerPixel <= 8 ) {
+  int bitsPerPixel=24;
+  char *videoInfo = getenv("PINBALL_BITPERPIXEL");
+  if (videoInfo) {
+    bitsPerPixel= atoi(videoInfo);
+  }
+  
+  if (bitsPerPixel <= 8 ) {
     SDL_GL_SetAttribute( SDL_GL_RED_SIZE, 2 );
     SDL_GL_SetAttribute( SDL_GL_GREEN_SIZE, 3 );
     SDL_GL_SetAttribute( SDL_GL_BLUE_SIZE, 3 );
-  } else        if ( SDL_GetVideoInfo()->vfmt->BitsPerPixel <= 16 ) {
+  } else if (bitsPerPixel <= 16 ) {
     SDL_GL_SetAttribute( SDL_GL_RED_SIZE, 5 );
     SDL_GL_SetAttribute( SDL_GL_GREEN_SIZE, 5 );
     SDL_GL_SetAttribute( SDL_GL_BLUE_SIZE, 5 );
@@ -174,17 +178,26 @@ void TextureUtil::initGrx() {
   SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
 
   /* Initialize the display */
-  SDL_Surface* screen =
-    SDL_SetVideoMode(config->getWidth(), config->getHeight(), config->getBpp(),
-                     SDL_OPENGL
-                     | (config->useFullScreen() ? SDL_FULLSCREEN : 0));
+  SDL_Renderer *sdlRenderer;
+  Uint32 window_flags = SDL_WINDOW_OPENGL						\
+    | (config->useFullScreen() ? getenv("PINBALL_WINDOW_FULLSCREEN_DESKTOP") ?
+       SDL_WINDOW_FULLSCREEN_DESKTOP : SDL_WINDOW_FULLSCREEN
+       : 0);
+  #ifdef HAVE_OPENGLES
+  SDL_SetHint(SDL_HINT_RENDER_DRIVER, "opengles");
+  #endif
+  SDL_CreateWindowAndRenderer(0, 0, window_flags, &m_window, &sdlRenderer);
+  SDL_SetWindowSize(m_window, config->getWidth(), config->getHeight());
+  SDL_SetRenderDrawColor(sdlRenderer, 0, 0, 0, 255);
+  SDL_RenderClear(sdlRenderer);
+  SDL_RenderPresent(sdlRenderer);
 
   //    if (config->useFullScreen()) {
   SDL_ShowCursor(SDL_DISABLE);
   //    }
-  SDL_WM_SetCaption("Emilia Pinball", NULL);
+  SDL_SetWindowTitle(m_window, "Emilia Pinball");
 
-  if (screen == NULL) {
+  if (m_window == NULL) {
     cerr << "Couldn't set video mode: " << SDL_GetError() << endl;
     exit(1);
   }
@@ -204,8 +217,10 @@ void TextureUtil::initGrx() {
   cerr << "SDL_GL_BLUE_SIZE: " << value << endl;
   SDL_GL_GetAttribute( SDL_GL_DEPTH_SIZE, &value );
   cerr << "SDL_GL_DEPTH_SIZE: " << value << endl;
+  #ifndef HAVE_OPENGLES
   SDL_GL_GetAttribute( SDL_GL_DOUBLEBUFFER, &value );
   cerr << "SDL_GL_DOUBLEBUFFER: " << value << endl << endl;
+  #endif
 
   this->resizeView(config->getWidth(), config->getHeight());
 #endif // EM_USE_SDL
@@ -288,7 +303,11 @@ void TextureUtil::resizeView(unsigned int w, unsigned int h) {
   glViewport(0, 0, (GLsizei) w, (GLsizei) h);
 
   glClearColor(m_colClear.r, m_colClear.g, m_colClear.b, m_colClear.a);
+  #ifdef HAVE_OPENGLES
+  glClearDepthf(1.0f);
+  #else
   glClearDepth(1.0);
+  #endif
 
   glShadeModel(GL_SMOOTH);
 
@@ -305,9 +324,15 @@ void TextureUtil::resizeView(unsigned int w, unsigned int h) {
   float ratio = Config::getInstance()->getRatio();
   if (ratio>=1 || ratio<=0) ratio=1; //TODO
 
+  #ifdef HAVE_OPENGLES
+  glFrustumf(-EM_RIGHT*EM_NEAR*ratio, EM_RIGHT*EM_NEAR*ratio,
+	    -EM_UP*EM_NEAR, EM_UP*EM_NEAR,
+            EM_NEAR, EM_FAR);
+  #else
   glFrustum(-EM_RIGHT*EM_NEAR*ratio, EM_RIGHT*EM_NEAR*ratio,
 	    -EM_UP*EM_NEAR, EM_UP*EM_NEAR,
             EM_NEAR, EM_FAR);
+  #endif
   glMatrixMode(GL_MODELVIEW);
 
 #if OPENGL_LIGHTS
