@@ -1,10 +1,10 @@
- # !/bin/sh
-# XPDX-License-Identifier: GPL-2.0+"
+#! /bin/sh
+# SPDX-License-Identifier: GPL-2.0+
 
 PINBALL_PROFILE="pincab"
 
 # TODO: pin version
-PINBALL_BRANCH="latest"
+PINBALL_BRANCH="master"
 
 # Output screen
 # PINBALL_SCREEN="DVI-I-1"
@@ -25,12 +25,15 @@ PINBALL_TABLE=
 # export PINBALL_QUIT
 
 # Readonly FS
-HOME="/tmp"
+HOME="/tmp/${PINBALL_PROFILE}"
 
-PINBALL_DISPLAY_MANAGER="xinit"
-DISPLAY=':0'
-XINITRC="/etc/pinball/pinball-session.sh"
-PINBALL_XRANDR_ARGS="--rotate left --mode ${PINBALL_RESOLUTION}"
+# Graphical system : weston or xinit
+PINBALL_DISPLAY_MANAGER='weston'
+XDG_RUNTIME_DIR='/run/user/0'
+#PINBALL_DISPLAY_MANAGER="xinit"
+#DISPLAY=':0'
+#XINITRC="/etc/pinball/pinball-session.sh"
+#PINBALL_XRANDR_ARGS="--rotate left --mode ${PINBALL_RESOLUTION}"
 
 DBUS_SESSION_BUS_ADDRESS='unix:path=/run/user/0/dbus/user_bus_socket'
 # ALSA_CARD=""
