@@ -223,14 +223,18 @@ protected:
     if (menuscreen->getCurrent() == 0) {
       if (config->useFullScreen() == false) {
 #if EM_USE_SDL
-        SDL_WM_ToggleFullScreen(SDL_GetVideoSurface());
+	SDL_SetWindowFullscreen(TextureUtil::getInstance()->getWindow(),
+				SDL_WINDOW_FULLSCREEN);
 #endif
       }
       config->setFullScreen(true);
     } else {
       if (config->useFullScreen() == true) {
 #if EM_USE_SDL
-        SDL_WM_ToggleFullScreen(SDL_GetVideoSurface());
+	SDL_SetWindowFullscreen(TextureUtil::getInstance()->getWindow(), 0);
+	SDL_SetWindowSize(TextureUtil::getInstance()->getWindow(),
+			  config->getWidth(), config->getHeight());
+        TextureUtil::getInstance()->resizeView(config->getWidth(), config->getHeight());
 #endif
       }
       config->setFullScreen(false);
@@ -273,10 +277,8 @@ protected:
     default: w = 640; h = 480;
     }
     if (config->getWidth() != w) {
-#ifdef  EM_USE_SDL
-      SDL_SetVideoMode(w, h, config->getBpp(),
-                       SDL_OPENGL
-                       | (config->useFullScreen() ? SDL_FULLSCREEN : 0));
+#if  EM_USE_SDL
+      SDL_SetWindowSize(TextureUtil::getInstance()->getWindow(), w, h);
 #endif // SDL
       TextureUtil::getInstance()->resizeView(w, h);
       //!rzr!+   //cout<<("Workround bug (for WIN32) + macosx etc");
@@ -732,6 +734,7 @@ MenuItem* createMenus(Engine * engine) {
 Pinball::Pinball()
   : mpMenu{}, mpEngine{}, miCount{}, miMaxCount{}
 {
+  PINBALL(FUNCT());
   char* var= getenv("PINBALL_QUIT");
   if (var) {
     if (*var) { miMaxCount = atoi(var); }
@@ -741,6 +744,7 @@ Pinball::Pinball()
 
 int Pinball::run(int argc, char *argv[])
 {
+  PINBALL(FUNCT());
   int status = 0;
   try {
     status |= setup(argc, argv);
@@ -765,6 +769,30 @@ int Pinball::run(int argc, char *argv[])
 
 int Pinball::setup(int argc, char *argv[])
 {
+  PINBALL(FUNCT());
+  for (auto i=0; i<argc; i++) {
+    if ((strcmp(argv[i], "--version") == 0)
+        || (strcmp(argv[i], "-v") == 0)) {
+      cout << PACKAGE_STRING << endl;
+      exit(EXIT_SUCCESS);
+    } else if ((strcmp(argv[i], "--help") == 0) 
+               || (strcmp(argv[i], "-h") == 0)) {
+      cout << "Usage: pinball [OPTIONS]" << endl << endl
+           << "Supported environment variables:" << endl << endl
+           << "# PINBALL_QUIT (number of frame before exit)" << endl
+           << "# PINBALL_TABLE (name of table or random)" << endl
+           << "# PINBALL_WINDOW_FULLSCREEN_DESKTOP (SDL)" << endl
+           << "# PINBALL_RENDER_DRIVER (3D)" << endl
+           << "# PINBALL_BITPERPIXEL (SDL)" << endl;
+#if EM_USE_SDL
+      for (int i=0; i<SDL_GetNumVideoDrivers(); i++)
+        cout << "# SDL_VIDEODRIVER='" << SDL_GetVideoDriver(i) << "'"
+             << endl;
+#endif
+      exit(EXIT_SUCCESS);
+    }
+  }
+
   // Create a engine and parse emilia arguments
   Config::getInstance()->loadConfig();
   mpEngine = new Engine(argc, argv);
@@ -799,7 +827,9 @@ int Pinball::setup(int argc, char *argv[])
 
   // cerr<<"log: pinball: Draw to the screen"<<endl;
   miCount = 0;
-
+  char* text = getenv("PINBALL_SPEED");
+  int fps = (text) ? atoi(text) : 8*25;
+  mpEngine->setSpeed(fps);
   mpEngine->resetTick();
   mpEngine->swap();
 
@@ -821,12 +851,14 @@ int Pinball::setup(int argc, char *argv[])
       Keyboard::clear();
     }
   }
+  mpEngine->resetTick();
   return 0;
 }
 
 
 int Pinball::loop()
 {
+  PINBALL(FUNCT());
   if (miMaxCount && miCount >= miMaxCount) {
     return 1;
   }
@@ -864,7 +896,7 @@ int Pinball::loop()
   if (Keyboard::isKeyDown(SDLK_r)) {
     SendSignal(PBL_SIG_RESET_ALL, 0, mpEngine, NULL);
   }
-  if (mpEngine->nextTickFPS(200)) {
+  if (mpEngine->nextTick()) {
     mpEngine->tick();
   } else {
     mpEngine->render();
@@ -885,6 +917,7 @@ int Pinball::loop()
 
 int Pinball::finish(int status)
 {
+  PINBALL(FUNCT());
   Config::getInstance()->saveConfig();
 
     // Write high scores to disk - pnf
@@ -897,9 +930,10 @@ int Pinball::finish(int status)
 
 int Pinball::main(int argc, char *argv[])
 {
+  PINBALL(FUNCT());
   Pinball instance;
   int status = instance.run(argc, argv);
-  cout<<"pinball: exit: "<<status<<endl;
+  cout << "pinball: exit: " << status << " fps: " << Engine::getFps() << endl;
   return status;
 }
 
@@ -973,6 +1007,7 @@ extern "C" {
 int WINAPI WinMain( HINSTANCE hInst,  HINSTANCE hPreInst,
                     LPSTR lpszCmdLine,  int nCmdShow )
 {
+  PINBALL(FUNCT());
   int argc=0; char** argv = 0;
   convertStringWords( GetCommandLine(), &argc, &argv);
 
@@ -985,6 +1020,7 @@ int WINAPI WinMain( HINSTANCE hInst,  HINSTANCE hPreInst,
 
 int main(int argc, char *argv[])
 {
+  PINBALL(FUNCT());
   int status = EXIT_SUCCESS;
   status |=  Pinball::main(argc, argv);
   return status;
